From: Clemens Wyss Date: 2001-08-16T18:34:12+09:00 Subject: [ruby-talk:19876] Re: how to speed up hash script? ....using "slice()" instead of "[...]" and "hash()" instead of "to_int()" might result in yet another improvement! I.e.: .... for i in 1...@num_lines @dict[(@lines[i].slice(0,@len_date)).hash()] = i end .... Pls. report, if you encounter any (in-)significant gain ;-) Regards Clemens Gerry Wiener wrote: > Thanks Sean, using > > GC.disable > # code > GC.enable > > cut another 4 seconds off the total time bringing the run time to > approximately 7 seconds. > > --Gerry > > >